@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: input.c,v 1.21 2005/08/04 12:43:26 cegger Exp $
 ******************************************************************************
 
    DirectX inputlib
@@ -28,7 +28,7 @@
 */
 
 #include "config.h"
-#include <ggi/internal/gii_target.h>
+#include <ggi/gg.h>
 
 #include <dxinput.h>
 #include <wctype.h>
@@ -71,15 +71,15 @@ get_system_keyboard_repeat(gii_di_priv *priv)
 		/* Default to 25 Hz */
 		priv->repeat_speed = 40000;
 
-	GIIDPRINT("input-directx: key delay %d us, key repeat %d us.\n",
-		priv->repeat_delay,
-		priv->repeat_speed);
+	DPRINT("input-directx: key delay %d us, key repeat %d us.\n",
+	       priv->repeat_delay,
+	       priv->repeat_speed);
 }
 
 /* Caps lock does not seem to work. Why the h*ll not? */
 
 static void
-set_key_state(BYTE *keystate, uint32 modifiers)
+set_key_state(BYTE *keystate, uint32_t modifiers)
 {
 	keystate[VK_SHIFT]   = (modifiers & GII_MOD_SHIFT) ? 0x80 : 0;
 	keystate[VK_CONTROL] = (modifiers & GII_MOD_CTRL)  ? 0x80 : 0;
@@ -90,7 +90,7 @@ set_key_state(BYTE *keystate, uint32 modifiers)
 /* Eliminate UTF-16 surrogate pairs. */
 
 static int
-utf16_to_utf32(WCHAR *utf16, int count16, uint32 *utf32)
+utf16_to_utf32(WCHAR *utf16, int count16, uint32_t *utf32)
 {
 	int count32 = 0;
 
@@ -123,7 +123,7 @@ utf16_to_utf32(WCHAR *utf16, int count16, uint32 *utf32)
 }
 
 static gii_event_mask
-send_synthetic_key(gii_input *inp, uint32 sym)
+send_synthetic_key(gii_input *inp, uint32_t sym)
 {
 	gii_di_priv *priv = DI_PRIV(inp);
 	gii_event ev;
@@ -162,13 +162,13 @@ send_synthetic_key(gii_input *inp, uint32 sym)
 /*#define MYWAY*/
 
 static gii_event_mask
-map_key(gii_input *inp, uint32 scan, uint32 *sym, uint32 *label)
+map_key(gii_input *inp, uint32_t scan, uint32_t *sym, uint32_t *label)
 {
 	gii_di_priv *priv = DI_PRIV(inp);
 	UINT vk;
 	static BYTE keystate[256];
 	WCHAR utf16[6];
-	uint32 utf32[2];
+	uint32_t utf32[2];
 	int res;
 	gii_event_mask ret = 0;
 
@@ -297,7 +297,7 @@ map_key(gii_input *inp, uint32 scan, uint32 *sym, uint32 *label)
 }
 
 static gii_event_mask
-GII_send_key(gii_input *inp, uint32 scan, uint8 press)
+GII_send_key(gii_input *inp, uint32_t scan, uint8_t press)
 {
 	gii_di_priv *priv = DI_PRIV(inp);
 	gii_event ev;
@@ -347,8 +347,8 @@ GII_send_key(gii_input *inp, uint32 scan, uint8 press)
 
 static gii_event_mask
 GII_send_ptr(gii_input *inp, int relative,
-	     uint32 type,  uint32 data,
-	     uint32 type2, uint32 data2)
+	     uint32_t type,  uint32_t data,
+	     uint32_t type2, uint32_t data2)
 {
 	gii_di_priv *priv = DI_PRIV(inp);
 	gii_event ev;
@@ -396,7 +396,7 @@ GII_send_ptr(gii_input *inp, int relative,
 
 
 static gii_event_mask
-GII_send_joy(gii_input *inp, gii_di_priv_dev *dev, uint32 type, uint32 data)
+GII_send_joy(gii_input *inp, gii_di_priv_dev *dev, uint32_t type, uint32_t data)
 {
 	gii_event ev;
 
@@ -471,7 +471,7 @@ GII_send_joy(gii_input *inp, gii_di_priv_dev *dev, uint32 type, uint32 data)
 
 /* Don't add more than 1000000 microseconds */
 static inline void
-tv_add_usec(struct timeval *tv, uint32 usec)
+tv_add_usec(struct timeval *tv, uint32_t usec)
 {
 	tv->tv_usec += usec;
 	if (tv->tv_usec >= 1000000) {
@@ -508,8 +508,8 @@ GII_di_poll(gii_input *inp, void *arg)
 	DWORD Joy_Elements;
 	POINT CurPos;
 	RECT WinSize;
-	uint32 i, j;
-	uint8 KB_Buffer[2 * GII_DX_BUFFER_SIZE];
+	uint32_t i, j;
+	uint8_t KB_Buffer[2 * GII_DX_BUFFER_SIZE];
 	DWORD Ptr_Buffer[2 * GII_DX_BUFFER_SIZE];
 	DWORD Joy_Buffer[2 * GII_DX_BUFFER_SIZE];
 	gii_event_mask return_mask = 0;
@@ -523,7 +523,7 @@ GII_di_poll(gii_input *inp, void *arg)
 		if (KB_Buffer[2 * i + 1] == 'D') {
 			if (now.tv_sec == 0)
 				ggCurTime(&now);
-			GIIDPRINT("gii_send_key: poll(%p);\n", inp);
+			DPRINT("gii_send_key: poll(%p);\n", inp);
 			return_mask |= GII_send_key(inp, KB_Buffer[2 * i], 1);
 
 			priv->repeat_key = -1;
@@ -726,7 +726,7 @@ GII_di_close(gii_input *inp)
 	}
 	free(priv);
 
-	GIIDPRINT_MISC("input-directx: closed\n");
+	DPRINT_MISC("input-directx: closed\n");
 
 	return 0;
 }
@@ -752,7 +752,7 @@ static gii_cmddata_getdevinfo di_devinfo_ptr =
 };
 
 static void
-send_devinfo(gii_input *inp, uint32 origin, gii_cmddata_getdevinfo *devinfo)
+send_devinfo(gii_input *inp, uint32_t origin, gii_cmddata_getdevinfo *devinfo)
 {
 	gii_event ev;
 	gii_cmddata_getdevinfo *dinfo;
@@ -773,12 +773,12 @@ send_devinfo(gii_input *inp, uint32 origin, gii_cmddata_getdevinfo *devinfo)
 }
 
 static int
-send_valinfo(gii_input *inp, uint32 origin, gii_di_priv_dev *dev, uint32 val)
+send_valinfo(gii_input *inp, uint32_t origin, gii_di_priv_dev *dev, uint32_t val)
 {
 	gii_event ev;
 	gii_cmddata_getvalinfo *vinfo;
 	gii_di_priv_obj *obj;
-	uint32 i;
+	uint32_t i;
 
 	if (val == GII_VAL_QUERY_ALL) {
 		for (i = 0; i < dev->devinfo.num_axes; ++i)
@@ -890,8 +890,9 @@ GIIsendevent(gii_input *inp, gii_event *ev)
 }
 
 
-int
-GIIdlinit(gii_input * inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_directx(gii_input * inp, const char *args, void *argptr);
+
+int GIIdl_directx(gii_input * inp, const char *args, void *argptr)
 {
 	gii_di_priv *priv;
 	gii_di_priv_dev *dev;
@@ -899,7 +900,7 @@ GIIdlinit(gii_input * inp, const char *args, void *argptr)
 	int ret;
 	int i;
 
-	GIIDPRINT_LIBS("DXINPUT HWND=%ld hInstance=%ld\n",
+	DPRINT_LIBS("DXINPUT HWND=%ld hInstance=%ld\n",
 		       (long)digii->hWnd, (long)digii->hInstance);
 
 	priv = malloc(sizeof(gii_di_priv));
@@ -934,9 +935,8 @@ GIIdlinit(gii_input * inp, const char *args, void *argptr)
 
 	ret = _gii_dx_InitDirectInput(priv, digii->hWnd, digii->hInstance);
 	if (ret != 0) {
-		GIIDPRINT_LIBS("input-directx: Unable to grab keyboard\n");
-		GIIDPRINT_LIBS("HWND=%ld rc=%d\n",
-			       (long)digii->hWnd, ret);
+		DPRINT_LIBS("input-directx: Unable to grab keyboard\n");
+		DPRINT_LIBS("HWND=%ld rc=%d\n", (long)digii->hWnd, ret);
 		free(priv);
 		return GGI_ENODEVICE;
 	}
