@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: input.c,v 1.17 2005/08/04 12:43:30 cegger Exp $
 ******************************************************************************
 
    Input-stdin: initialization
@@ -30,9 +30,10 @@
 #include <ctype.h>
 
 #include "config.h"
+
+#include <ggi/gg.h>
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
-#include <ggi/internal/gii_target.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -72,7 +73,7 @@ typedef struct stdin_hook
 /* ---------------------------------------------------------------------- */
 
 
-static gii_event_mask GII_send_key(gii_input *inp, uint32 sym)
+static gii_event_mask GII_send_key(gii_input *inp, uint32_t sym)
 {
 	gii_event ev;
 	
@@ -100,7 +101,7 @@ static gii_event_mask GII_stdin_poll(gii_input *inp, void *arg)
 	struct timeval	t={0,0};
 	unsigned char	buf[6];
 	
-	GIIDPRINT_EVENTS("input-stdin: poll(%p);\n",inp);
+	DPRINT_EVENTS("input-stdin: poll(%p);\n",inp);
 	
 	if (select(inp->maxfd, &readset, NULL, NULL, &t) <= 0) {
 		return 0;
@@ -109,7 +110,7 @@ static gii_event_mask GII_stdin_poll(gii_input *inp, void *arg)
 	read(STDIN_FD, buf, 1);
 
 	if (! priv->ansikey || (buf[0] != 27 /* escape */)) {
-		return GII_send_key(inp, (uint32) buf[0]);
+		return GII_send_key(inp, (uint32_t) buf[0]);
 	}
 
 	/* Wait a bit, to see if the character following escape was '['
@@ -122,15 +123,15 @@ static gii_event_mask GII_stdin_poll(gii_input *inp, void *arg)
 
 	if (select(inp->maxfd, &readset, NULL, NULL, &t) <= 0) {
 		/* Timed out : must have been plain escape key */
-		return GII_send_key(inp, (uint32) buf[0]);
+		return GII_send_key(inp, (uint32_t) buf[0]);
 	}
 	
 	read(STDIN_FD, buf+1, 1);
 
 	if (buf[1] != '[') {
 		/* Nope, not an ANSI key sequence */
-		GII_send_key(inp, (uint32) buf[0]);
-		return GII_send_key(inp, (uint32) buf[1]);
+		GII_send_key(inp, (uint32_t) buf[0]);
+		return GII_send_key(inp, (uint32_t) buf[1]);
 	}
 	
 	/* handle the ANSI key sequences */
@@ -139,10 +140,10 @@ static gii_event_mask GII_stdin_poll(gii_input *inp, void *arg)
 
 	buf[3] = buf[4] = buf[5] = 0;
 
-	if (isdigit(buf[2]) || (buf[2] == '[')) {
+	if (isdigit((uint8_t)(buf[2])) || (buf[2] == '[')) {
 	    read(STDIN_FD, buf+3, 1);
 	}
-	if (isdigit(buf[3])) {
+	if (isdigit((uint8_t)(buf[3]))) {
 	    read(STDIN_FD, buf+4, 1);
 	}
 	
@@ -182,7 +183,7 @@ static int GII_stdin_close(gii_input *inp)
 #endif
 	free(priv);
 
-	GIIDPRINT_MISC("input-stdin: closed\n");
+	DPRINT_MISC("input-stdin: closed\n");
 
 	return 0;
 }
@@ -270,13 +271,15 @@ static int GIIsendevent(gii_input *inp, gii_event *ev)
 }
 
 
-int GIIdlinit(gii_input *inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_stdin(gii_input *inp, const char *args, void *argptr);
+
+int GIIdl_stdin(gii_input *inp, const char *args, void *argptr)
 {
-	char *str;
+	const char *str;
 	stdin_priv *priv;
 	gg_option options[NUM_OPTS];
 
-	GIIDPRINT_MISC("input-stdin starting.(args=\"%s\",argptr=%p)\n",
+	DPRINT_MISC("input-stdin starting.(args=\"%s\",argptr=%p)\n",
 			args, argptr);
 
 	memcpy(options, optlist, sizeof(options));
@@ -293,7 +296,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	}
 	
 	if (args) {
-		args = ggParseOptions((char *)args, options, NUM_OPTS);
+		args = ggParseOptions(args, options, NUM_OPTS);
 		if (args == NULL) {
 			fprintf(stderr, "input-stdin: error in "
 				"arguments.\n");
@@ -313,7 +316,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	inp->priv = priv;
         
-	if (tolower((int)options[OPT_ANSIKEY].result[0]) != 'n') {
+	if (tolower((uint8_t)options[OPT_ANSIKEY].result[0]) != 'n') {
 		priv->ansikey=1;
 	} else {
 		priv->ansikey = 0;
@@ -321,7 +324,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	priv->rawmode = 0;
 #ifdef USE_TERMIOS
-	if (tolower((int)options[OPT_NORAW].result[0]) == 'n') {
+	if (tolower((uint8_t)options[OPT_NORAW].result[0]) == 'n') {
 		/* turn on `raw' mode (i.e. non-canonical mode) */
 		priv->rawmode = 1;
 		GII_stdin_setraw(inp);
@@ -338,7 +341,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	send_devinfo(inp);
 
-	GIIDPRINT_MISC("input-stdin fully up\n");
+	DPRINT_MISC("input-stdin fully up\n");
 
 	return 0;
 }
